pub trait TryIntoBody {
type Error;
// Required method
fn try_into_body(self) -> Result<Vec<u8>, Self::Error>;
}Expand description
A trait for any type that can be turned into a Response body or fail
pub trait TryIntoBody {
type Error;
// Required method
fn try_into_body(self) -> Result<Vec<u8>, Self::Error>;
}A trait for any type that can be turned into a Response body or fail