Json

Struct Json 

pub struct Json<T>(pub T);
Available on crate features http and json only.
A JSON wrapper for request and response bodies.

Wraps a value of type T and serializes it as JSON when used as a response, automatically setting the Content-Type: application/json header.

Examples

use spin_sdk::http::{Json, Request};
use spin_sdk::http_service;
use serde::Serialize;

#[derive(Serialize)]
struct User { name: String }

#[http_service]
async fn handler(_req: Request) -> impl IntoResponse {
    Json(User { name: "Alice".into() })
}

Tuple Fields

0: T