QueryResult

Struct QueryResult 

pub struct QueryResult { /* private fields */ }
Available on crate feature sqlite only.
The result of a Connection::execute operation.

Implementations

Source

impl QueryResult

pub fn columns(&self) -> &[String]

The columns in the query result.

pub async fn next(&mut self) -> Option<RowResult>

Gets the next row in the result set.

If this is None, there are no more rows available. You must await QueryResult::result() to determine if all rows were read successfully.

pub async fn result(self) -> Result<(), Error>

Whether the query completed successfully or with an error.

pub async fn collect(self) -> Result<Vec<RowResult>, Error>

Collect all rows in the result set.

This is provided for when the result set is small enough to fit in memory and you do not require streaming behaviour.

pub fn into_inner( self, ) -> (Vec<String>, StreamReader<RowResult>, FutureReader<Result<(), Error>>)

Extracts the underlying Wasm Component Model results of the query.