Module spin_sdk::http::conversions
source · Expand description
Traits for converting between the various types
Enums
- An error converting an
IncomingRequest
Traits
- A trait from converting from a body
- A trait for any type that can be turned into a
Responsebody - A trait for any type that can be turned into
Responseheaders - A trait for any type that can be turned into a
Response - A trait for any type that can be turned into a
Responsestatus code - A trait for converting from a body or failing
- A trait for trying to convert from an
IncomingRequestto the implementing type - A trait for converting from an
IncomingRequest - A trait for any type that can be constructor from a
Request - A trait for any type that can be turned into a
Responsebody or fail - A trait for converting a type into an
OutgoingRequest - Turn a type into a
Request - A hack that allows us to do blanket impls for
T where T: TryFromRequestfor all typesTexcept forRequest.