pub struct QueryResult { /* private fields */ }Available on crate feature
sqlite only.Expand description
The result of a Connection::execute operation.
Implementations
Sourceimpl QueryResult
impl QueryResult
Sourcepub async fn next(&mut self) -> Option<RowResult>
pub async fn next(&mut self) -> Option<RowResult>
Gets the next row in the result set.
If this is None, there are no more rows available. You must
await QueryResult::result() to determine if all rows
were read successfully.
Sourcepub async fn result(self) -> Result<(), Error>
pub async fn result(self) -> Result<(), Error>
Whether the query completed successfully or with an error.
Sourcepub async fn collect(self) -> Result<Vec<RowResult>, Error>
pub async fn collect(self) -> Result<Vec<RowResult>, Error>
Collect all rows in the result set.
This is provided for when the result set is small enough to fit in memory and you do not require streaming behaviour.
Sourcepub fn into_inner(
self,
) -> (Vec<String>, StreamReader<RowResult>, FutureReader<Result<(), Error>>)
pub fn into_inner( self, ) -> (Vec<String>, StreamReader<RowResult>, FutureReader<Result<(), Error>>)
Extracts the underlying Wasm Component Model results of the query.